ChatCompletionChunk

Struct ChatCompletionChunk 

pub struct ChatCompletionChunk {
    pub id: String,
    pub object: String,
    pub created: u64,
    pub model: String,
    pub choices: Vec<ChunkChoice>,
}
Wire types for chat completion requests, responses, and streaming. Server-Sent Events streaming types. Wire types for chat completion requests, responses, and streaming. Server-Sent Events streaming types. A single Server-Sent Events chunk from a streaming completion.

Fields

id: String

Opaque completion identifier (same across all chunks for one request).

object: String

Always "chat.completion.chunk".

created: u64

Unix timestamp of this chunk.

model: String

Model that generated this chunk.

choices: Vec<ChunkChoice>

One or more delta choices in this chunk.