pub struct Tool {
pub tool_type: String,
pub function: Function,
}Expand description
Wire types for chat completion requests, responses, and streaming.
Chat completion request, response, and message types.
Wire types for chat completion requests, responses, and streaming.
Chat completion request, response, and message types.
A function tool definition passed in the tools array of a request.
Fields
tool_type: StringAlways "function" for function-type tools.
function: FunctionFunction specification.
Implementations
Sourceimpl Tool
impl Tool
Sourcepub fn former() -> ToolFormer<ToolFormerDefinition<(), Tool, ReturnPreformed>>
pub fn former() -> ToolFormer<ToolFormerDefinition<(), Tool, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.
Sourceimpl Tool
impl Tool
Sourcepub fn function(
name: impl Into<String>,
description: impl Into<String>,
parameters: Value,
) -> Self
pub fn function( name: impl Into<String>, description: impl Into<String>, parameters: Value, ) -> Self
Convenience constructor for a function-type tool.
Examples
use api_openai_compatible::Tool;
let tool = Tool::function(
"get_weather",
"Get current weather for a location",
serde_json::json!({ "type": "object", "properties": {} }),
);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Tool
impl<'de> Deserialize<'de> for Tool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__Context, __Formed, __End> EntityToDefinition<__Context, __Formed, __End> for Toolwhere
__End: FormingEnd<ToolFormerDefinitionTypes<__Context, __Formed>>,
impl<__Context, __Formed, __End> EntityToDefinition<__Context, __Formed, __End> for Toolwhere
__End: FormingEnd<ToolFormerDefinitionTypes<__Context, __Formed>>,
Sourcetype Definition = ToolFormerDefinition<__Context, __Formed, __End>
type Definition = ToolFormerDefinition<__Context, __Formed, __End>
The specific
FormerDefinition associated with this entity. Read moreSourcetype Types = ToolFormerDefinitionTypes<__Context, __Formed>
type Types = ToolFormerDefinitionTypes<__Context, __Formed>
The specific
FormerDefinitionTypes associated with this entity. Read moreSourceimpl<__Context, __Formed> EntityToDefinitionTypes<__Context, __Formed> for Tool
impl<__Context, __Formed> EntityToDefinitionTypes<__Context, __Formed> for Tool
Sourceimpl<Definition> EntityToFormer<Definition> for Toolwhere
Definition: FormerDefinition<Storage = ToolFormerStorage>,
impl<Definition> EntityToFormer<Definition> for Toolwhere
Definition: FormerDefinition<Storage = ToolFormerStorage>,
Sourceimpl EntityToStorage for Tool
impl EntityToStorage for Tool
impl StructuralPartialEq for Tool