pub struct ChatCompletionRequest {
pub model: String,
pub messages: Vec<Message>,
pub temperature: Option<f32>,
pub max_tokens: Option<u32>,
pub top_p: Option<f32>,
pub frequency_penalty: Option<f32>,
pub presence_penalty: Option<f32>,
pub stream: Option<bool>,
pub tools: Option<Vec<Tool>>,
}Expand description
Wire types for chat completion requests, responses, and streaming.
Chat completion request, response, and message types.
Wire types for chat completion requests, responses, and streaming.
Chat completion request, response, and message types.
Request body for the POST chat/completions endpoint.
Uses the Former builder pattern for ergonomic construction.
Examples
use api_openai_compatible::{ ChatCompletionRequest, Message };
let req = ChatCompletionRequest::former()
.model( "gpt-4o".to_string() )
.messages( vec![ Message::user( "Hello!" ) ] )
.max_tokens( 100_u32 )
.form();Fields
model: StringModel identifier (e.g. "gpt-4o", "grok-2-1212").
messages: Vec<Message>Ordered list of conversation messages.
temperature: Option<f32>Sampling temperature in [0.0, 2.0]. Higher = more random.
max_tokens: Option<u32>Maximum tokens to generate in the completion.
top_p: Option<f32>Nucleus sampling threshold in [0.0, 1.0].
frequency_penalty: Option<f32>Frequency penalty in [0.0, 2.0] (reduces token repetition).
presence_penalty: Option<f32>Presence penalty in [0.0, 2.0] (encourages topic diversity).
stream: Option<bool>When true, the response is streamed as Server-Sent Events.
tools: Option<Vec<Tool>>Tool definitions available for function calling.
Implementations
Sourceimpl ChatCompletionRequest
impl ChatCompletionRequest
Sourcepub fn former() -> ChatCompletionRequestFormer<ChatCompletionRequestFormerDefinition<(), ChatCompletionRequest, ReturnPreformed>>
pub fn former() -> ChatCompletionRequestFormer<ChatCompletionRequestFormerDefinition<(), ChatCompletionRequest, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.